USBQualityTest — pywws 13.06_r1023 documentation

### Navigation

- index
- modules |
- suivant |
- précédent |
- pywws 13.06_r1023 documentation »
- Programmes et des modules Python »

# USBQualityTest

Teste la qualité de la connexion USB avec votre station météo

    usage: python -m pywws.USBQualityTest [options]
    options are:
     -h | --help           display this help
     -v | --verbose        increase amount of reassuring messages
                           (repeat for even more messages e.g. -vvv)

La liaison USB à ma station n’est pas fiable à 100%. Les données lues à partir de la station par l’ordinateur sont occasionnellement corrompues, peut-être par une interférence. J’ai essayé de résoudre ce problème en mettant une perle de ferrite autour du câble USB et le déplaçant des sources d’interférences possibles, tels que les disques durs externes. Le tout sans succès jusqu’à présent.

Ce programme teste la connexion USB en lisant de manière continue toute la mémoire de la station météo (sauf les parties qui peuvent être changeantes) à la recherche d’erreurs. Chaque bloc de 32 octets est lu deux fois, et si les deux lectures diffèrent, un message d’avertissement s’affiche. Sont également affichés le nombre de blocs lus, et le nombre d’erreurs rencontrées.

I typically get one or two errors per hour, so the test needs to be run for several hours to produce a useful measurement. Note that other software that accesses the weather station (such as Hourly or LiveLog) must not be run while the test is in progress.

Si vous exécutez ce test et obtenez absolument aucune erreur, s’il vous plaît faites le moi savoir. Il y a quelque chose de spécial dans votre configuration et j’aimerais bien savoir ce que c’est

Fonctions

`main`([argv]) |

`pywws.USBQualityTest.` `main`(argv=None)

### Navigation

- index
- modules |
- suivant |
- précédent |
- pywws 13.06_r1023 documentation »
- Programmes et des modules Python »